<template>
  <gree-popup v-model="isShow" position="bottom" get-container="body" @hide="hidePopup">
    <div class="lr-Swing-Area-popup">
      <p class="title" v-text="title" />
      <a class="tips" v-text="tips" />
      <btn-group :btn-list="btnList" />
    </div>
  </gree-popup>
</template>

<script>
import { Popup } from 'gree-ui';
import { mapMutations, mapActions, mapState, mapGetters } from 'vuex';
import { types } from '@/store/types';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';

export default {
  name: 'lr-Swing-Area-popup',
  components: {
    [Popup.name]: Popup,
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup
  },
  data() {
    return {
      isShow: false
    };
  },
  computed: {
    ...mapState('control', {
      swingLRPicker: state => state.popup.swingLRPicker
    }),
    ...mapGetters(['swingLRAreaModels']),
    ...mapGetters('machine', ['statusLoop', 'statusMap']),
    btnList() {
      const result = [];
      // console.log('swingLRModels', this.swingLRModels);
      this.swingLRAreaModels.forEach(model => {
        const statusNameList = this.getLoop(model);
        statusNameList.forEach(statusName => {
          const { identifier } = model;
          const currentStatusName = this.getCurrentStatusName(identifier);
          const stateName = `${identifier}_${statusName}`;
          // status定义
          const status = model.statusDefine[statusName];
          // 名称
          const statusNameText = status.name;
          const stateNameText = this.$language(`${statusNameText}`);
          // 图标
          const icon = {
            key: status.icon.key,
            type: currentStatusName === statusName ? 'on' : 'off'
          };
          // 是否置灰
          const gray = false;
          // 是否隐藏
          const hide = status.icon.key === 'disable';
          // 跳转页面
          const page = false;
          // 执行的函数
          const handler = (_, disable = false) => {
            disable || this.$stateMachine.toStatus(identifier, statusName);
          };
          result.push({ key: stateName, name: stateNameText, icon, gray, hide, page, handler });
        });
      });
      return result;
    },
    title() {
      return this.$language('btn.ConstLRGrid');
    },
    tips() {
      return this.$language('ConstLR.tips');
    }
  },
  watch: {
    isShow(newVal) {
      !newVal && this.SetPopup({ swingLRPicker: false });
    },
    swingLRPicker: {
      handler(newVal) {
        this.isShow = newVal;
      },
      immediate: true
    }
  },
  methods: {
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({
      sendCtrl: types.SEND_CTRL
    }),
    hidePopup() {
      this.SetPopup({ swingLRPicker: false });
    },
    getLoop(model) {
      if (!model) return [];
      const { identifier } = model;
      let result = JSON.parse(JSON.stringify(this.statusLoop[identifier]));
      const startStatusName = 'default';
      const defaultIndex = result.findIndex(statusName => statusName === startStatusName);
      result.unshift(...result.splice(defaultIndex));
      return result;
    },
    getCurrentStatusName(identifier) {
      return String(this.statusMap[identifier].statusName);
    }
  }
};
</script>

<style lang="scss">
.lr-Swing-Area-popup {
  width: 100%;
  background-color: #fff;
  &-title {
    padding-top: 30px;
    text-align: center;
    font-size: 50px;
  }
}
</style>
